@@ -30,10 +30,8 @@
 #'   data frames.
 #'
 #' @param targets Character vector, names of targets to build.
-#'   Dependencies are built too. Together, the `plan` and
-#'   `targets` comprise the workflow network
-#'   (i.e. the `graph` argument).
-#'   Changing either will change the network.
+#'   Dependencies are built too. You may supply static and/or whole
+#'   dynamic targets, but no sub-targets.
 #'
 #' @param envir Environment to use. Defaults to the current
 #'   workspace, so you should not need to worry about this
@@ -369,16 +367,7 @@
 #'   back-off: say,
 #'   `function(i) { 0.1 + 120 * pexp(i - 1, rate = 0.01) }`.
 #'
-#' @param hasty_build A user-defined function.
-#'   In "hasty mode" (`make(parallelism = "hasty")`)
-#'   this is the function that evaluates a target's command
-#'   and returns the resulting value. The `hasty_build` argument
-#'   has no effect if `parallelism` is any value other than "hasty".
-#'
-#'   The function you pass to `hasty_build` must have arguments `target`
-#'   and `config`. Here, `target` is a character scalar naming the
-#'   target being built, and `config` is a configuration list of
-#'   runtime parameters generated by [drake_config()].
+#' @param hasty_build Deprecated
 #'
 #' @param spec Deprecated.
 #'
@@ -588,18 +577,22 @@ drake_config <- function(
   deprecate_arg(makefile_path, "makefile_path")
   deprecate_arg(layout, "layout", "spec") # 2019-12-15
   deprecate_arg(console_log_file, "console_log_file", "log_make") # 2020-02-08
-  session_info <- resolve_session_info(session_info)
+  # 2020-03-21
+  if (!is.character(parallelism)) {
+    warn0("Custom parallel backends in drake are deprecated. Using \"loop\".")
+    parallelism <- "loop"
+  }
   memory_strategy <- match.arg(memory_strategy, choices = memory_strategies())
   if (memory_strategy == "memory") {
     memory_strategy <- "preclean"
-    warning(
+    warn0(
       "make(memory_strategy = \"memory\") is deprecated. ",
-      "Use make(memory_strategy = \"preclean\") instead",
-      call. = FALSE
+      "Use make(memory_strategy = \"preclean\") instead"
       # 2019-06-22 # nolint
     )
   }
   force(envir)
+  session_info <- resolve_session_info(session_info)
   plan <- sanitize_plan(plan, envir = envir)
   plan_checks(plan)
   targets <- sanitize_targets(targets, plan)
@@ -611,6 +604,7 @@ drake_config <- function(
   if (length(formats)) {
     formats <- na_omit(formats)
   }
+  check_formats(formats)
   sleep <- `environment<-`(sleep, new.env(parent = globalenv()))
   if (is.null(cache)) {
     cache <- new_cache()
@@ -653,58 +647,62 @@ drake_config <- function(
   envir_graph <- new.env(parent = emptyenv())
   meta <- new.env(parent = emptyenv())
   meta_old <- new.env(parent = emptyenv())
+  settings <- new_drake_settings(
+    cache_log_file = cache_log_file,
+    curl_handles = curl_handles,
+    garbage_collection = garbage_collection,
+    jobs = jobs,
+    jobs_preprocess = jobs_preprocess,
+    keep_going = keep_going,
+    lazy_load = lazy_load,
+    lib_loc = lib_loc,
+    lock_cache = lock_cache,
+    lock_envir = lock_envir,
+    log_build_times = log_build_times,
+    log_progress = log_progress,
+    memory_strategy = memory_strategy,
+    parallelism = parallelism,
+    recover = recover,
+    recoverable = recoverable,
+    seed = seed,
+    session_info = session_info,
+    skip_imports = skip_imports,
+    skip_safety_checks = skip_safety_checks,
+    skip_targets = skip_targets,
+    sleep = sleep,
+    template = template
+  )
   out <- list(
-    envir = envir,
+    cache = cache,
+    logger = logger,
+    packages = packages,
+    prework = prework,
+    settings = settings,
+    spec = spec,
+    # Data clump of metadata
+    meta = meta,
+    meta_old = meta_old,
+    # Data clump of graphs
     envir_graph = envir_graph,
+    graph = graph,
+    # Data clump of environments for memory management
+    envir = envir,
     envir_targets = envir_targets,
     envir_dynamic = envir_dynamic,
     envir_loaded = envir_loaded,
     envir_subtargets = envir_subtargets,
-    cache = cache,
-    parallelism = parallelism,
-    jobs = jobs,
-    jobs_preprocess = jobs_preprocess,
-    logger = logger,
-    packages = packages,
-    lib_loc = lib_loc,
-    prework = prework,
-    spec = spec,
-    meta = meta,
-    meta_old = meta_old,
-    graph = graph,
-    seed = seed,
-    trigger = trigger,
-    timeout = timeout,
-    cpu = cpu,
-    elapsed = elapsed,
-    retries = retries,
-    skip_targets = skip_targets,
-    skip_imports = skip_imports,
-    skip_safety_checks = skip_safety_checks,
-    log_progress = log_progress,
-    lazy_load = lazy_load,
-    session_info = session_info,
-    cache_log_file = cache_log_file,
-    caching = caching,
-    keep_going = keep_going,
-    memory_strategy = memory_strategy,
-    garbage_collection = garbage_collection,
-    template = template,
-    sleep = sleep,
-    hasty_build = hasty_build,
-    lock_envir = lock_envir,
-    force = force,
-    recover = recover,
-    recoverable = recoverable,
-    curl_handles = curl_handles,
+    # Data clump of hash tables
     ht_dynamic_deps = ht_dynamic_deps,
     ht_is_dynamic = ht_is_dynamic,
     ht_is_subtarget = ht_is_subtarget, # Gets replaced in make()
-    max_expand = max_expand,
-    log_build_times = log_build_times,
+    # All this should go in individual target specs
+    caching = caching,
+    cpu = cpu,
+    elapsed = elapsed,
     format = format,
-    formats = formats,
-    lock_cache = lock_cache
+    max_expand = max_expand,
+    retries = retries,
+    trigger = trigger
   )
   class(out) <- c("drake_config", "drake")
   config_checks(out)
@@ -724,10 +722,22 @@ drake_config2 <- drake_config_parent(n = 2L)
 
 #' @export
 print.drake_config <- function(x, ...) {
-  cat("a configured drake workflow\n")
+  cat("drake_config\n")
   min_str(x)
 }
 
+# TODO: should be a validate method.
+assert_config <- function(config) {
+  if (inherits(config, "drake_config")) {
+    return()
+  }
+  stop0(
+    "the ",
+    shQuote("config"),
+    " argument must be a drake_config() object."
+  )
+}
+
 resolve_session_info <- function(x) {
   out <- x %|||% Sys.getenv("drake_session_info")
   if (is.logical(out)) {
@@ -788,15 +798,14 @@ sanitize_targets <- function(targets, plan) {
   targets <- make.names(targets, unique = FALSE, allow_ = TRUE)
   not_found <- setdiff(targets, plan$target)
   if (length(not_found)) {
-    warning(
+    warn0(
       "ignoring targets not in the drake plan:\n",
-      multiline_message(not_found),
-      call. = FALSE
+      multiline_message(not_found)
     )
   }
   out <- unique(intersect(targets, plan$target))
   if (!length(out)) {
-    stop("no valid targets specified.", call. = FALSE)
+    stop0("no valid targets specified.")
   }
   out
 }
@@ -848,33 +857,31 @@ plan_checks <- function(plan) {
 
 plan_check_required_cols <- function(plan) {
   if (!all(c("target", "command") %in% colnames(plan))) {
-    stop(
+    stop0(
       "The columns of your workflow plan data frame ",
-      "must include 'target' and 'command'.",
-      call. = FALSE
+      "must include 'target' and 'command'."
     )
   }
 }
 
 plan_check_bad_symbols <- function(plan) {
   if (any(bad_symbols %in% plan$target)) {
-    stop(
+    stop0(
       "symbols that cannot be target names: \n",
-      multiline_message(shQuote(bad_symbols)),
-      call. = FALSE
+      multiline_message(shQuote(bad_symbols))
     )
   }
 }
 
 config_checks <- function(config) {
-  if (identical(config$skip_safety_checks, TRUE)) {
+  if (identical(config$settings$skip_safety_checks, TRUE)) {
     return(invisible())
   }
   check_case_sensitivity(config)
   check_drake_graph(graph = config$graph)
   cache_vers_stop(config$cache)
-  check_parallelism(config$parallelism, config$jobs)
-  check_jobs(config$jobs)
+  check_parallelism(config$settings$parallelism, config$settings$jobs)
+  check_jobs(config$settings$jobs)
 }
 
 check_case_sensitivity <- function(config) {
@@ -886,16 +893,11 @@ check_case_sensitivity <- function(config) {
     return()
   }
   dups <- sort(x[which(lower %in% lower[i])])
-  warning(
-    "Duplicated target/import names when converting to lowercase:\n",
-    multiline_message(dups),
-    "\nDuplicates cause problems on Windows ",
-    "because the file system is case insensitive. Options:\n",
-    "  (1) Make your target/import names more unique.\n",
-    "  (2) Use a more portable custom cache, ",
-    "e.g. make(cache = storr::storr_rds(mangle_key = TRUE))\n",
-    "  (3) Avoid Windows.",
-    call. = FALSE
+  warn0(
+    "Duplicated target/import names when converting to lowercase. ",
+    "Either de-duplicate them or mangle keys: ",
+    "make(cache = storr::storr_rds(mangle_key = TRUE)). Duplicates found:\n",
+    multiline_message(dups)
   )
 }
 
@@ -910,17 +912,16 @@ check_drake_graph <- function(graph) {
     out <- paste(out, collapse = " ")
   })
   cycles <- unlist(cycles)
-  stop(
+  stop0(
     "Circular workflow:\n",
     "  at least one target in your drake plan\n",
     "  ultimately depends on itself.\n",
     "If you believe a dependency was detected in error\n",
     "  (example: https://github.com/ropensci/drake/issues/578)\n",
-    "  then consider using ignore() to mask sections \n",
+    "  then consider using ignore() or no_deps() to mask sections\n",
     "  of your commands or imported functions.\n",
     "Cycles:\n",
-    multiline_message(cycles),
-    call. = FALSE
+    multiline_message(cycles)
   )
 }
 
@@ -928,16 +929,10 @@ check_parallelism <- function(parallelism, jobs) {
   stopifnot(is.character(parallelism) || is.function(parallelism))
   stopifnot(length(parallelism) > 0)
   if (length(parallelism) > 1) {
-    stop(
-      "The `parallelism` argument of `make()` should be of length 1.",
-      call. = FALSE
-    )
+    stop0("The parallelism argument of make() should be of length 1.")
   }
   if (identical(parallelism, "loop") && jobs > 1L) {
-    warning(
-      "In make(), `parallelism` should not be \"loop\" if `jobs` > 1",
-      call. = FALSE
-    )
+    warn0("In make(), parallelism should not be \"loop\" if jobs > 1.")
   }
 }
 
@@ -946,11 +941,9 @@ check_jobs <- function(jobs) {
   stopifnot(is.numeric(jobs) || is.integer(jobs))
   stopifnot(all(jobs > 0))
   if (length(jobs) > 1) {
-    stop(
-      "The `jobs` argument of `make()` should be of length 1. ",
-      "Use the `jobs_preprocess` argument to parallelize the imports ",
-      "and other preprocessing tasks.",
-      call. = FALSE
+    stop0(
+      "The jobs argument of make() should be of length 1. ",
+      "Use the jobs_preprocess argument to parallelize the imports etc."
     )
   }
 }
