@@ -1,19 +1,5 @@
 drake_context("analysis")
 
-test_with_dir("drake_validate.drake_deps() (#1183)", {
-  x <- new_drake_deps()
-  expect_silent(drake_validate(x))
-  x$globals <- NULL
-  expect_error(drake_validate(x))
-})
-
-test_with_dir("drake_validate.drake_deps_ht() (#1183)", {
-  x <- new_drake_deps_ht()
-  expect_silent(drake_validate(x))
-  x$globals <- NULL
-  expect_error(drake_validate(x))
-})
-
 test_with_dir("busy function", {
   f <- function(a = 1, b = k(i), nineteen, string_args = c("sa1", "sa2")) {
     for (iter in 1:10) {
@@ -39,7 +25,7 @@ test_with_dir("busy function", {
     f2 <- "local"
     lm(f1 ~ f2 + f3)
     file_in("x", "y")
-    drake::file_out(c("w", "z"))
+    drake::file_in(c("w", "z"))
     base::c(got, basevar)
     quote(quoted)
     Quote(quoted2)
@@ -47,8 +33,7 @@ test_with_dir("busy function", {
   }
   out <- drake_deps(f)
   out <- select_nonempty(decode_deps_list(out))
-  expect_equal(sort(out$file_in), sort(c("x", "y")))
-  expect_equal(sort(out$file_out), sort(c("w", "z")))
+  expect_equal(sort(out$file_in), sort(c("w", "x", "y", "z")))
   str <- sort(
     c("iter3", "iter4", "local", paste0("string", 1:3), "sa1", "sa2")
   )
@@ -410,7 +395,7 @@ test_with_dir("bad target names", {
   expect_error(drake_config(plan), "cannot be target names")
 })
 
-test_with_dir("file_out() and knitr_in(): commands vs imports", {
+test_with_dir("file_in() and file_out() and knitr_in(): commands vs imports", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   skip_if_not_installed("knitr")
   cmd <- quote({
@@ -418,8 +403,6 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
   })
   f <- function() {
     file_in("x")
-    file_out("y")
-    knitr_in("report.Rmd")
   }
   file.create("x")
   file.create("y")
@@ -429,13 +412,17 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
     mustWork = TRUE
   )
   file.copy(
-    from = path, to = file.path(getwd(), "report.Rmd"), overwrite = TRUE)
+    from = path,
+    to = file.path(getwd(), "report.Rmd"),
+    overwrite = TRUE
+  )
   x <- cds_command_dependencies(cmd)
   x <- select_nonempty(decode_deps_list(x))
   x0 <- list(
     file_in = "x", file_out = "y", loadd = "large",
     readd = c("small", "coef_regression2_small"),
-    knitr_in = "report.Rmd")
+    knitr_in = "report.Rmd"
+  )
   expect_equal(length(x), length(x0))
   for (i in names(x)) {
     expect_equal(sort(x[[i]]), sort(x0[[i]]))
@@ -443,10 +430,7 @@ test_with_dir("file_out() and knitr_in(): commands vs imports", {
   y <- cds_import_dependencies(f)
   y <- select_nonempty(decode_deps_list(y))
   y0 <- list(
-    file_in = "x",
-    knitr_in = "report.Rmd",
-    loadd = "large",
-    readd = c("small", "coef_regression2_small")
+    file_in = "x"
   )
   expect_equal(length(y), length(y0))
   for (i in names(y)) {
@@ -492,10 +476,13 @@ test_with_dir("deps_code() and deps_target_impl()", {
     botched = read.csv(file_in(nothing)),
     meta = read.table(file_in("file_in"))
   )
-  config <- drake_config(
-    my_plan,
-    session_info = FALSE,
-    cache = storr::storr_environment()
+  expect_warning(
+    config <- drake_config(
+      my_plan,
+      session_info = FALSE,
+      cache = storr::storr_environment()
+    ),
+    regexp = "must be literal strings"
   )
   expect_equal(deps_code(my_plan$command[[1]])$name, "some_object")
   expect_equal(
@@ -505,9 +492,12 @@ test_with_dir("deps_code() and deps_target_impl()", {
     sort(deps_code(my_plan$command[[3]])$name),
     sort(c("f", "g", "w", "x", "y", "z"))
   )
-  expect_equal(
-    sort(deps_code(my_plan$command[[4]])$name),
-    sort(c("read.csv"))
+  expect_warning(
+    expect_equal(
+      sort(deps_code(my_plan$command[[4]])$name),
+      sort(c("read.csv"))
+    ),
+    regexp = "must be literal strings"
   )
   expect_equal(
     sort(deps_code(my_plan$command[[5]])$name),
@@ -552,7 +542,7 @@ test_with_dir("missing input files", {
   expect_warning(tmp <- missing_input_files(config))
   expect_silent(tmp <- config_checks(config))
   expect_warning(runtime_checks(config), regexp = "missing")
-  config$skip_safety_checks <- TRUE
+  config$settings$skip_safety_checks <- TRUE
   expect_silent(tmp <- runtime_checks(config))
 })
 
@@ -1076,3 +1066,24 @@ test_with_dir("$<-() and @<-() (#1144)", {
   }
   expect_equal(sort(deps_code(f)$name), sort(c("g", "x")))
 })
+
+test_with_dir("nonliteral file_in() (#1229)", {
+  expect_silent(
+    x <- deps_code(quote(file_in(c("file1", "file2"))))
+  )
+  expect_warning(
+    x <- deps_code(quote(file_in(paste("file1", "file2")))),
+    regexp = "must be literal strings"
+  )
+})
+
+test_with_dir("no file_out() or knitr_in() in imported fns (#1229)", {
+  expect_error(
+    deps_code(function(x) file_out("abc")),
+    regexp = "file_out"
+  )
+  expect_error(
+    suppressWarnings(deps_code(function(x) knitr_in("abc"))),
+    regexp = "knitr_in"
+  )
+})
