@@ -39,11 +39,11 @@ test_with_dir("clean() removes the correct files", {
   clean(cache = cache, garbage_collection = TRUE)
   expect_true(file.exists("a.txt"))
   expect_true(file.exists("b.txt"))
-  expect_false(file.exists("d.rds"))
+  expect_true(file.exists("d.rds"))
   expect_true(dir.exists("abc"))
-  expect_false(dir.exists("xyz"))
+  expect_true(dir.exists("xyz"))
   expect_true(file.exists("abc/c.txt"))
-  expect_false(file.exists("xyz/e.txt"))
+  expect_true(file.exists("xyz/e.txt"))
 })
 
 test_with_dir("drake_version", {
@@ -81,7 +81,7 @@ test_with_dir("dependency profile", {
   expect_false(any(deps_profile_impl(target = a, config = config)$changed))
   b <- 2
   expect_false(any(deps_profile_impl(target = a, config = config)$changed))
-  config$skip_targets <- TRUE
+  config$settings$skip_targets <- TRUE
   make_impl(config = config)
   dp <- deps_profile_impl(target = a, config = config)
   expect_true(as.logical(dp[dp$name == "depend", "changed"]))
@@ -257,8 +257,8 @@ test_with_dir("cache functions work from various working directories", {
   }
   with_dir(scratch, {
     expect_equal(nrow(build_times()), 0)
-    expect_equal(nrow(progress()), 0)
-    expect_false(any("in progress" %in% progress()))
+    expect_equal(nrow(drake_progress()), 0)
+    expect_false(any("in progress" %in% drake_progress()))
     expect_error(readd())
     config <- dbug()
     using_global <- identical(config$envir, globalenv())
@@ -268,7 +268,7 @@ test_with_dir("cache functions work from various working directories", {
       envir <- environment()
     }
 
-    config$session_info <- TRUE
+    config$settings$session_info <- TRUE
     testrun(config)
 
     # drake_cache_log() # nolint
@@ -315,14 +315,14 @@ test_with_dir("cache functions work from various working directories", {
     n1 <- nrow(bt)
 
     # find stuff in current directory session, progress
-    expect_equal(read_drake_seed(), config$seed)
+    expect_equal(read_drake_seed(), config$settings$seed)
     expect_true(is.list(drake_get_session_info()))
-    expect_true(all(progress()$progress == "done"))
-    expect_false(any("running" %in% progress()))
-    expect_equal(sort(progress()$target), sort(config$plan$target))
+    expect_true(all(drake_progress()$progress == "done"))
+    expect_false(any("running" %in% drake_progress()))
+    expect_equal(sort(drake_progress()$target), sort(config$plan$target))
     exp <- weak_tibble(target = "final", progress = "done")
-    expect_equal(progress(final), exp)
-    expect_equal(progress(list = "final"), exp)
+    expect_equal(drake_progress(final), exp)
+    expect_equal(drake_progress(list = "final"), exp)
 
     # cached, diagnose, rescue
     expect_true(length(diagnose()) > length(config$plan$target))
@@ -365,10 +365,10 @@ test_with_dir("cache functions work from various working directories", {
   with_dir(s, {
     # progress, session
     expect_true(is.list(drake_get_session_info()))
-    prog <- progress()
+    prog <- drake_progress()
     expect_equal(sort(prog$target), sort(config$plan$target))
     expect_true(all(prog$progress == "done"))
-    prog2 <- progress(nothing)
+    prog2 <- drake_progress(nothing)
     expect_equal(prog, prog2)
 
     # cached and diagnose
@@ -402,24 +402,24 @@ test_with_dir("cache functions work from various working directories", {
 
     # clean
     expect_true(all(config$plan$target %in% cached()))
-    clean(final, jobs = 2, garbage_collection = TRUE)
+    clean(final, garbage_collection = TRUE)
     targs <- setdiff(config$plan$target, "final")
     expect_true(all(targs %in% cached()))
     drake_gc()
 
     # Test purging
-    prog <- progress()
+    prog <- drake_progress()
     expect_true("final" %in% prog$target)
 
-    clean(final, jobs = 2, garbage_collection = TRUE, purge = TRUE)
-    prog <- progress()
+    clean(final, garbage_collection = TRUE, purge = TRUE)
+    prog <- drake_progress()
     expect_false("final" %in% prog$target)
 
     # progress is erased with cache rescue
     rescue_cache(targets = "final")
-    expect_true(nrow(progress()) > 0L)
+    expect_true(nrow(drake_progress()) > 0L)
     rescue_cache(garbage_collection = FALSE)
-    expect_equal(nrow(progress()), 0L)
+    expect_equal(nrow(drake_progress()), 0L)
     rescue_cache(garbage_collection = TRUE)
 
     # More cleaning checks
@@ -507,7 +507,7 @@ test_with_dir("selection and filtering in progress", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   plan <- drake_plan(x_a = TRUE, y_b = x_a, x_c = stop(y_b))
   expect_error(make(plan))
-  out <- progress(x_a, y_b, x_c, d)
+  out <- drake_progress(x_a, y_b, x_c, d)
   exp <- weak_tibble(
     target = c("x_a", "y_b", "x_c"),
     progress = c("done", "done", "failed")
@@ -529,12 +529,12 @@ test_with_dir("selection and filtering in progress", {
     target = c("x_a", "x_c"),
     progress = c("done", "failed")
   )
-  expect_equivalent(progress(progress = c("done", "failed")), exp1)
-  expect_equivalent(progress(progress = "done"), exp2)
-  expect_equivalent(progress(progress = "failed"), exp3)
-  expect_error(progress(progress = "stuck"), "should be one of")
+  expect_equivalent(drake_progress(progress = c("done", "failed")), exp1)
+  expect_equivalent(drake_progress(progress = "done"), exp2)
+  expect_equivalent(drake_progress(progress = "failed"), exp3)
+  expect_error(drake_progress(progress = "stuck"), "should be one of")
   skip_if_not_installed("tidyselect")
-  expect_equivalent(progress(tidyselect::starts_with("x_")), exp4)
+  expect_equivalent(drake_progress(tidyselect::starts_with("x_")), exp4)
   cache <- drake_cache()
   expect_equal(cache$get_progress("12345"), "none")
 })
@@ -574,7 +574,7 @@ test_with_dir("loadd(x, deps = TRUE) when x is not cached", {
   expect_equal(e$x, "abc")
   expect_message(
     loadd(y, envir = e, config = config, deps = TRUE, tidyselect = TRUE),
-    regexp = "Disabling"
+    regexp = "Disabled"
   )
 })
 
@@ -586,7 +586,7 @@ test_with_dir("clean: garbage_collection and destroy", {
   expect_true(file.exists("abc"))
   clean(garbage_collection = TRUE, destroy = TRUE)
   expect_false(file.exists(".drake"))
-  expect_false(file.exists("abc"))
+  expect_true(file.exists("abc"))
 })
 
 test_with_dir("fancy cache features, bad paths", {
@@ -793,9 +793,9 @@ test_with_dir("arbitrary storr in-memory cache", {
   expect_equal(length(o1), 6)
   expect_false(file.exists(cached_data))
 
-  p1 <- progress(verbose = 0L)
+  p1 <- drake_progress(verbose = 0L)
   unlink(default_cache_path(), recursive = TRUE)
-  p2 <- progress(cache = cache, verbose = 0L)
+  p2 <- drake_progress(cache = cache, verbose = 0L)
   expect_true(nrow(p2) > nrow(p1))
   expect_false(file.exists(cached_data))
 
@@ -843,18 +843,18 @@ test_with_dir("try_build() does not need to access cache", {
   skip_on_cran() # CRAN gets whitelist tests only (check time limits).
   config <- drake_config(drake_plan(x = 1), lock_envir = FALSE)
   meta <- drake_meta_(target = "x", config = config)
-  config$cache <- config$cache_log_file <- NULL
+  config$cache <- config$settings$cache_log_file <- NULL
   build <- try_build(target = "x", meta = meta, config = config)
   expect_equal(1, build$value)
   expect_error(drake_build_impl(target = "x", config = config))
 })
 
-test_with_dir("running()", {
+test_with_dir("drake_running()", {
   skip_on_cran()
   plan <- drake_plan(a = 1)
   cache <- storr::storr_environment()
   make(plan, session_info = FALSE, cache = cache)
-  expect_equal(running(cache = cache), character(0))
+  expect_equal(drake_running(cache = cache), character(0))
   config <- drake_config(plan, cache = cache, log_progress = TRUE)
   config$running_make <- TRUE
   set_progress(
@@ -862,7 +862,7 @@ test_with_dir("running()", {
     value = "running",
     config = config
   )
-  expect_equal(running(cache = cache), "a")
+  expect_equal(drake_running(cache = cache), "a")
 })
 
 test_with_dir("need a storr for a decorated storr", {
@@ -942,3 +942,17 @@ test_with_dir("suppress cache locking (#1081)", {
   expect_equal(outdated_impl(config), character(0))
   expect_equal(recoverable_impl(config), character(0))
 })
+
+test_with_dir("drake_done() (#1205)", {
+  skip_on_cran()
+  plan <- drake_plan(x = 1, y = x)
+  make(plan)
+  expect_equal(sort(drake_done()), sort(c("x", "y")))
+})
+
+test_with_dir("drake_cancelled() (#1205)", {
+  skip_on_cran()
+  plan <- drake_plan(x = 1, y = cancel_if(x > 0))
+  make(plan)
+  expect_equal(drake_cancelled(), "y")
+})
